class Constants:
    # well-known environment variables
    APPLICATION_INSIGHTS_CONNECTION_STRING = "_AGENT_RUNTIME_APP_INSIGHTS_CONNECTION_STRING"
    AGENT_ID = "AGENT_ID"
    AGENT_PROJECT_RESOURCE_ID = "AGENT_PROJECT_NAME"
