# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    Annotation,
    AnnotationFileCitation,
    AnnotationFilePath,
    AnnotationUrlCitation,
    ApproximateLocation,
    CodeInterpreterOutput,
    CodeInterpreterOutputImage,
    CodeInterpreterOutputLogs,
    CodeInterpreterTool,
    CodeInterpreterToolAuto,
    CodeInterpreterToolCallItemParam,
    CodeInterpreterToolCallItemResource,
    ComputerAction,
    ComputerActionClick,
    ComputerActionDoubleClick,
    ComputerActionDrag,
    ComputerActionKeyPress,
    ComputerActionMove,
    ComputerActionScreenshot,
    ComputerActionScroll,
    ComputerActionTypeKeys,
    ComputerActionWait,
    ComputerToolCallItemParam,
    ComputerToolCallItemResource,
    ComputerToolCallOutputItemOutput,
    ComputerToolCallOutputItemOutputComputerScreenshot,
    ComputerToolCallOutputItemParam,
    ComputerToolCallOutputItemResource,
    ComputerToolCallSafetyCheck,
    ComputerUsePreviewTool,
    Coordinate,
    CreateResponseText,
    Error,
    FileSearchTool,
    FileSearchToolCallItemParam,
    FileSearchToolCallItemParamResult,
    FileSearchToolCallItemResource,
    FunctionTool,
    FunctionToolCallItemParam,
    FunctionToolCallItemResource,
    FunctionToolCallOutputItemParam,
    FunctionToolCallOutputItemResource,
    ImageGenTool,
    ImageGenToolCallItemParam,
    ImageGenToolCallItemResource,
    ImageGenToolInputImageMask,
    ImplicitUserMessage,
    ItemContent,
    ItemContentInputAudio,
    ItemContentInputFile,
    ItemContentInputImage,
    ItemContentInputText,
    ItemContentOutputAudio,
    ItemContentOutputText,
    ItemContentRefusal,
    ItemParam,
    ItemReferenceItemParam,
    ItemResource,
    LocalShellExecAction,
    LocalShellTool,
    LocalShellToolCallItemParam,
    LocalShellToolCallItemResource,
    LocalShellToolCallOutputItemParam,
    LocalShellToolCallOutputItemResource,
    Location,
    LogProb,
    MCPApprovalRequestItemParam,
    MCPApprovalRequestItemResource,
    MCPApprovalResponseItemParam,
    MCPApprovalResponseItemResource,
    MCPCallItemParam,
    MCPCallItemResource,
    MCPListToolsItemParam,
    MCPListToolsItemResource,
    MCPListToolsTool,
    MCPTool,
    MCPToolAllowedTools1,
    MCPToolRequireApproval1,
    MCPToolRequireApprovalAlways,
    MCPToolRequireApprovalNever,
    Prompt,
    RankingOptions,
    Reasoning,
    ReasoningItemParam,
    ReasoningItemResource,
    ReasoningItemSummaryPart,
    ReasoningItemSummaryTextPart,
    Response,
    ResponseCodeInterpreterCallCodeDeltaEvent,
    ResponseCodeInterpreterCallCodeDoneEvent,
    ResponseCodeInterpreterCallCompletedEvent,
    ResponseCodeInterpreterCallInProgressEvent,
    ResponseCodeInterpreterCallInterpretingEvent,
    ResponseCompletedEvent,
    ResponseContentPartAddedEvent,
    ResponseContentPartDoneEvent,
    ResponseCreatedEvent,
    ResponseError,
    ResponseErrorEvent,
    ResponseErrorResponse,
    ResponseFailedEvent,
    ResponseFileSearchCallCompletedEvent,
    ResponseFileSearchCallInProgressEvent,
    ResponseFileSearchCallSearchingEvent,
    ResponseFormatJsonSchemaSchema,
    ResponseFunctionCallArgumentsDeltaEvent,
    ResponseFunctionCallArgumentsDoneEvent,
    ResponseImageGenCallCompletedEvent,
    ResponseImageGenCallGeneratingEvent,
    ResponseImageGenCallInProgressEvent,
    ResponseImageGenCallPartialImageEvent,
    ResponseInProgressEvent,
    ResponseIncompleteDetails1,
    ResponseIncompleteEvent,
    ResponseItemList,
    ResponseMCPCallArgumentsDeltaEvent,
    ResponseMCPCallArgumentsDoneEvent,
    ResponseMCPCallCompletedEvent,
    ResponseMCPCallFailedEvent,
    ResponseMCPCallInProgressEvent,
    ResponseMCPListToolsCompletedEvent,
    ResponseMCPListToolsFailedEvent,
    ResponseMCPListToolsInProgressEvent,
    ResponseOutputItemAddedEvent,
    ResponseOutputItemDoneEvent,
    ResponsePromptVariables,
    ResponseQueuedEvent,
    ResponseReasoningDeltaEvent,
    ResponseReasoningDoneEvent,
    ResponseReasoningSummaryDeltaEvent,
    ResponseReasoningSummaryDoneEvent,
    ResponseReasoningSummaryPartAddedEvent,
    ResponseReasoningSummaryPartDoneEvent,
    ResponseReasoningSummaryTextDeltaEvent,
    ResponseReasoningSummaryTextDoneEvent,
    ResponseRefusalDeltaEvent,
    ResponseRefusalDoneEvent,
    ResponseStreamEvent,
    ResponseTextDeltaEvent,
    ResponseTextDoneEvent,
    ResponseTextFormatConfiguration,
    ResponseTextFormatConfigurationJsonObject,
    ResponseTextFormatConfigurationJsonSchema,
    ResponseTextFormatConfigurationText,
    ResponseUsage,
    ResponseUsageInputTokensDetails,
    ResponseUsageOutputTokensDetails,
    ResponseWebSearchCallCompletedEvent,
    ResponseWebSearchCallInProgressEvent,
    ResponseWebSearchCallSearchingEvent,
    ResponsesAssistantMessageItemParam,
    ResponsesAssistantMessageItemResource,
    ResponsesDeveloperMessageItemParam,
    ResponsesDeveloperMessageItemResource,
    ResponsesMessageItemParam,
    ResponsesMessageItemResource,
    ResponsesSystemMessageItemParam,
    ResponsesSystemMessageItemResource,
    ResponsesUserMessageItemParam,
    ResponsesUserMessageItemResource,
    Tool,
    ToolChoiceObject,
    ToolChoiceObjectCodeInterpreter,
    ToolChoiceObjectComputer,
    ToolChoiceObjectFileSearch,
    ToolChoiceObjectFunction,
    ToolChoiceObjectImageGen,
    ToolChoiceObjectMCP,
    ToolChoiceObjectWebSearch,
    TopLogProb,
    WebSearchAction,
    WebSearchActionFind,
    WebSearchActionOpenPage,
    WebSearchActionSearch,
    WebSearchPreviewTool,
    WebSearchToolCallItemParam,
    WebSearchToolCallItemResource,
)

from ._enums import (  # type: ignore
    AnnotationType,
    CodeInterpreterOutputType,
    ComputerActionType,
    ComputerToolCallOutputItemOutputType,
    Includable,
    ItemContentType,
    ItemType,
    LocationType,
    ModelIdsResponses,
    ReasoningEffort,
    ReasoningItemSummaryPartType,
    ResponseErrorCode,
    ResponseStreamEventType,
    ResponseTextFormatConfigurationType,
    ResponsesMessageRole,
    ServiceTier,
    ToolChoiceObjectType,
    ToolChoiceOptions,
    ToolType,
    WebSearchActionType,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Annotation",
    "AnnotationFileCitation",
    "AnnotationFilePath",
    "AnnotationUrlCitation",
    "ApproximateLocation",
    "CodeInterpreterOutput",
    "CodeInterpreterOutputImage",
    "CodeInterpreterOutputLogs",
    "CodeInterpreterTool",
    "CodeInterpreterToolAuto",
    "CodeInterpreterToolCallItemParam",
    "CodeInterpreterToolCallItemResource",
    "ComputerAction",
    "ComputerActionClick",
    "ComputerActionDoubleClick",
    "ComputerActionDrag",
    "ComputerActionKeyPress",
    "ComputerActionMove",
    "ComputerActionScreenshot",
    "ComputerActionScroll",
    "ComputerActionTypeKeys",
    "ComputerActionWait",
    "ComputerToolCallItemParam",
    "ComputerToolCallItemResource",
    "ComputerToolCallOutputItemOutput",
    "ComputerToolCallOutputItemOutputComputerScreenshot",
    "ComputerToolCallOutputItemParam",
    "ComputerToolCallOutputItemResource",
    "ComputerToolCallSafetyCheck",
    "ComputerUsePreviewTool",
    "Coordinate",
    "CreateResponseText",
    "Error",
    "FileSearchTool",
    "FileSearchToolCallItemParam",
    "FileSearchToolCallItemParamResult",
    "FileSearchToolCallItemResource",
    "FunctionTool",
    "FunctionToolCallItemParam",
    "FunctionToolCallItemResource",
    "FunctionToolCallOutputItemParam",
    "FunctionToolCallOutputItemResource",
    "ImageGenTool",
    "ImageGenToolCallItemParam",
    "ImageGenToolCallItemResource",
    "ImageGenToolInputImageMask",
    "ImplicitUserMessage",
    "ItemContent",
    "ItemContentInputAudio",
    "ItemContentInputFile",
    "ItemContentInputImage",
    "ItemContentInputText",
    "ItemContentOutputAudio",
    "ItemContentOutputText",
    "ItemContentRefusal",
    "ItemParam",
    "ItemReferenceItemParam",
    "ItemResource",
    "LocalShellExecAction",
    "LocalShellTool",
    "LocalShellToolCallItemParam",
    "LocalShellToolCallItemResource",
    "LocalShellToolCallOutputItemParam",
    "LocalShellToolCallOutputItemResource",
    "Location",
    "LogProb",
    "MCPApprovalRequestItemParam",
    "MCPApprovalRequestItemResource",
    "MCPApprovalResponseItemParam",
    "MCPApprovalResponseItemResource",
    "MCPCallItemParam",
    "MCPCallItemResource",
    "MCPListToolsItemParam",
    "MCPListToolsItemResource",
    "MCPListToolsTool",
    "MCPTool",
    "MCPToolAllowedTools1",
    "MCPToolRequireApproval1",
    "MCPToolRequireApprovalAlways",
    "MCPToolRequireApprovalNever",
    "Prompt",
    "RankingOptions",
    "Reasoning",
    "ReasoningItemParam",
    "ReasoningItemResource",
    "ReasoningItemSummaryPart",
    "ReasoningItemSummaryTextPart",
    "Response",
    "ResponseCodeInterpreterCallCodeDeltaEvent",
    "ResponseCodeInterpreterCallCodeDoneEvent",
    "ResponseCodeInterpreterCallCompletedEvent",
    "ResponseCodeInterpreterCallInProgressEvent",
    "ResponseCodeInterpreterCallInterpretingEvent",
    "ResponseCompletedEvent",
    "ResponseContentPartAddedEvent",
    "ResponseContentPartDoneEvent",
    "ResponseCreatedEvent",
    "ResponseError",
    "ResponseErrorEvent",
    "ResponseErrorResponse",
    "ResponseFailedEvent",
    "ResponseFileSearchCallCompletedEvent",
    "ResponseFileSearchCallInProgressEvent",
    "ResponseFileSearchCallSearchingEvent",
    "ResponseFormatJsonSchemaSchema",
    "ResponseFunctionCallArgumentsDeltaEvent",
    "ResponseFunctionCallArgumentsDoneEvent",
    "ResponseImageGenCallCompletedEvent",
    "ResponseImageGenCallGeneratingEvent",
    "ResponseImageGenCallInProgressEvent",
    "ResponseImageGenCallPartialImageEvent",
    "ResponseInProgressEvent",
    "ResponseIncompleteDetails1",
    "ResponseIncompleteEvent",
    "ResponseItemList",
    "ResponseMCPCallArgumentsDeltaEvent",
    "ResponseMCPCallArgumentsDoneEvent",
    "ResponseMCPCallCompletedEvent",
    "ResponseMCPCallFailedEvent",
    "ResponseMCPCallInProgressEvent",
    "ResponseMCPListToolsCompletedEvent",
    "ResponseMCPListToolsFailedEvent",
    "ResponseMCPListToolsInProgressEvent",
    "ResponseOutputItemAddedEvent",
    "ResponseOutputItemDoneEvent",
    "ResponsePromptVariables",
    "ResponseQueuedEvent",
    "ResponseReasoningDeltaEvent",
    "ResponseReasoningDoneEvent",
    "ResponseReasoningSummaryDeltaEvent",
    "ResponseReasoningSummaryDoneEvent",
    "ResponseReasoningSummaryPartAddedEvent",
    "ResponseReasoningSummaryPartDoneEvent",
    "ResponseReasoningSummaryTextDeltaEvent",
    "ResponseReasoningSummaryTextDoneEvent",
    "ResponseRefusalDeltaEvent",
    "ResponseRefusalDoneEvent",
    "ResponseStreamEvent",
    "ResponseTextDeltaEvent",
    "ResponseTextDoneEvent",
    "ResponseTextFormatConfiguration",
    "ResponseTextFormatConfigurationJsonObject",
    "ResponseTextFormatConfigurationJsonSchema",
    "ResponseTextFormatConfigurationText",
    "ResponseUsage",
    "ResponseUsageInputTokensDetails",
    "ResponseUsageOutputTokensDetails",
    "ResponseWebSearchCallCompletedEvent",
    "ResponseWebSearchCallInProgressEvent",
    "ResponseWebSearchCallSearchingEvent",
    "ResponsesAssistantMessageItemParam",
    "ResponsesAssistantMessageItemResource",
    "ResponsesDeveloperMessageItemParam",
    "ResponsesDeveloperMessageItemResource",
    "ResponsesMessageItemParam",
    "ResponsesMessageItemResource",
    "ResponsesSystemMessageItemParam",
    "ResponsesSystemMessageItemResource",
    "ResponsesUserMessageItemParam",
    "ResponsesUserMessageItemResource",
    "Tool",
    "ToolChoiceObject",
    "ToolChoiceObjectCodeInterpreter",
    "ToolChoiceObjectComputer",
    "ToolChoiceObjectFileSearch",
    "ToolChoiceObjectFunction",
    "ToolChoiceObjectImageGen",
    "ToolChoiceObjectMCP",
    "ToolChoiceObjectWebSearch",
    "TopLogProb",
    "WebSearchAction",
    "WebSearchActionFind",
    "WebSearchActionOpenPage",
    "WebSearchActionSearch",
    "WebSearchPreviewTool",
    "WebSearchToolCallItemParam",
    "WebSearchToolCallItemResource",
    "AnnotationType",
    "CodeInterpreterOutputType",
    "ComputerActionType",
    "ComputerToolCallOutputItemOutputType",
    "Includable",
    "ItemContentType",
    "ItemType",
    "LocationType",
    "ModelIdsResponses",
    "ReasoningEffort",
    "ReasoningItemSummaryPartType",
    "ResponseErrorCode",
    "ResponseStreamEventType",
    "ResponseTextFormatConfigurationType",
    "ResponsesMessageRole",
    "ServiceTier",
    "ToolChoiceObjectType",
    "ToolChoiceOptions",
    "ToolType",
    "WebSearchActionType",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
